==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/WebPageCancellableEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCancelableEventArgsDetailDescriptionMetadata } from "./WebCancelableEventArgsDetailDescriptionMetadata";
import { WebPageCancellableEventArgsDetailDescription } from "./WebPageCancellableEventArgsDetailDescription";
/**
 * @hidden
 */
export let WebPageCancellableEventArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebPageCancellableEventArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebPageCancellableEventArgsDetailDescriptionMetadata.a == null) {
                WebPageCancellableEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebPageCancellableEventArgsDetailDescriptionMetadata.c(WebPageCancellableEventArgsDetailDescriptionMetadata.a);
            }
            if (a.k(WebPageCancellableEventArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebPageCancellableEventArgsDetailDescriptionMetadata.a);
        }
        static c(a) {
            WebCancelableEventArgsDetailDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:PageCancellableEventArgsDetail");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Current", "Number:double");
            a.item("Next", "Number:double");
        }
        static d(a) {
            WebPageCancellableEventArgsDetailDescriptionMetadata.b(a);
            a.ad("WebPageCancellableEventArgsDetail", () => new WebPageCancellableEventArgsDetailDescription());
            a.ac("WebPageCancellableEventArgsDetail", WebPageCancellableEventArgsDetailDescriptionMetadata.a);
        }
    }
    WebPageCancellableEventArgsDetailDescriptionMetadata.$t = /*@__PURE__*/ markType(WebPageCancellableEventArgsDetailDescriptionMetadata, 'WebPageCancellableEventArgsDetailDescriptionMetadata');
    WebPageCancellableEventArgsDetailDescriptionMetadata.a = null;
    return WebPageCancellableEventArgsDetailDescriptionMetadata;
})();

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm2015/lib/WebPageCancellableEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCancelableEventArgsDetailDescriptionMetadata } from "./WebCancelableEventArgsDetailDescriptionMetadata";
import { WebPageCancellableEventArgsDetailDescription } from "./WebPageCancellableEventArgsDetailDescription";
/**
 * @hidden
 */
export let WebPageCancellableEventArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebPageCancellableEventArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebPageCancellableEventArgsDetailDescriptionMetadata.a == null) {
                WebPageCancellableEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebPageCancellableEventArgsDetailDescriptionMetadata.c(WebPageCancellableEventArgsDetailDescriptionMetadata.a);
            }
            if (a.k(WebPageCancellableEventArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebPageCancellableEventArgsDetailDescriptionMetadata.a);
        }
        static c(a) {
            WebCancelableEventArgsDetailDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:PageCancellableEventArgsDetail");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Current", "Number:double");
            a.item("Next", "Number:double");
        }
        static d(a) {
            WebPageCancellableEventArgsDetailDescriptionMetadata.b(a);
            a.ae("WebPageCancellableEventArgsDetail", () => new WebPageCancellableEventArgsDetailDescription());
            a.ad("WebPageCancellableEventArgsDetail", WebPageCancellableEventArgsDetailDescriptionMetadata.a);
        }
    }
    WebPageCancellableEventArgsDetailDescriptionMetadata.$t = /*@__PURE__*/ markType(WebPageCancellableEventArgsDetailDescriptionMetadata, 'WebPageCancellableEventArgsDetailDescriptionMetadata');
    WebPageCancellableEventArgsDetailDescriptionMetadata.a = null;
    return WebPageCancellableEventArgsDetailDescriptionMetadata;
})();
